@@ -46,38 +46,86 @@ b += 1000
 #:
 
 
-#: E225
-i=i+1
 #: E225
 submitted +=1
 #: E225
-x = x*2 - 1
-#: E225
-hypot2 = x*x + y*y
-#: E225
-c = (a+b) * (a-b)
-#: E225
-c = (a + b)*(a - b)
-#: E225
-c = (a +b)*(a - b)
+submitted+= 1
 #: E225
 c =-1
 #: E225
+x = x /2 - 1
+#: E225
 c = alpha -4
 #: E225
+c = alpha- 4
+#: E225
+z = x **y
+#: E225
 z = (x + 1) **y
 #: E225
-norman = True+False
+z = (x + 1)** y
 #: E225
-_1MB = 2 ** 20
 _1kB = _1MB >>10
+#: E225
+_1kB = _1MB>> 10
+#: E225
+i=i+ 1
+#: E225
+i=i +1
+#: E225 E226
+i=i+1
+#: E225 E226
+i =i+1
+#: E225 E226
+i= i+1
+#: E225 E226
+c = (a +b)*(a - b)
+#: E225 E226
+c = (a+ b)*(a - b)
 #:
+
+#: E226
+z = 2**30
+#: E226
+c = (a+b) * (a-b)
+#: E226
+norman = True+False
+#: E226
+x = x*2 - 1
+#: E226
+x = x/2 - 1
+#: E226
+hypot2 = x*x + y*y
+#: E226
+c = (a + b)*(a - b)
+#: E226
+def squares(n):
+    return (i**2 for i in range(n))
+#: E227
+_1kB = _1MB>>10
+#: E227
+_1MB = _1kB<<10
+#: E227
+a = b|c
+#: E227
+b = c&a
+#: E227
+c = b^a
+#: E228
+a = b%c
+#: E228
+msg = fmt%(errno, errmsg)
+#: E228
+msg = "Error %d occured"%errno
+#:
+
 #: Okay
 i = i + 1
 submitted += 1
 x = x * 2 - 1
 hypot2 = x * x + y * y
 c = (a + b) * (a - b)
+_1MB = 2 ** 20
 foo(bar, key='word', *args, **kwargs)
 baz(**kwargs)
 negative = -1
@@ -88,7 +136,13 @@ lambda a, b=h[:], c=0: (a, b, c)
 if not -5 < x < +5:
     print >>sys.stderr, "x is out of range."
 print >> sys.stdout, "x is an integer."
+z = 2 ** 30
+x = x / 2 - 1
 
-if True:
+if alpha[:-i]:
     *a, b = (1, 2, 3)
+
+
+def squares(n):
+    return (i ** 2 for i in range(n))
 #:
