@@ -15,3 +15,5 @@ foo(bar=(1 == 1))
 foo(bar=(1 != 1))
 foo(bar=(1 >= 1))
 foo(bar=(1 <= 1))
+(options, args) = parser.parse_args()
+d[type(None)] = _deepcopy_atomic
